@@ -1,4 +1,4 @@
-#include "HsUnix.h"
+#include "HsUnixConfig.h"
 #include <sys/types.h>
 
 unsigned int unix_major(dev_t dev);
