@@ -11,7 +11,6 @@ module System.PosixCompat (
     , module System.PosixCompat.Time
     , module System.PosixCompat.Types
     , module System.PosixCompat.Unistd
-    , module System.PosixCompat.User
     , usingPortableImpl
     ) where
 
@@ -20,7 +19,6 @@ import System.PosixCompat.Temp
 import System.PosixCompat.Time
 import System.PosixCompat.Types
 import System.PosixCompat.Unistd
-import System.PosixCompat.User
 
 -- | 'True' if unix-compat is using its portable implementation,
 --   or 'False' if the unix package is simply being re-exported.
